@@ -36,6 +36,7 @@ Finally, ack takes settings from the command line.
 use strict;
 use warnings;
 
+use App::Ack::ConfigDefault;
 use Cwd 3.00 ();
 use File::Spec 3.00;
 
@@ -154,4 +155,33 @@ sub find_config_files {
     return _remove_redundancies( @config_files );
 }
 
+=head2 read_rcfile
+
+Reads the contents of the .ackrc file and returns the arguments.
+
+=cut
+
+sub read_rcfile {
+    my $file = shift;
+
+    return unless defined $file && -e $file;
+
+    my @lines;
+
+    open( my $fh, '<', $file ) or App::Ack::die( "Unable to read $file: $!" );
+    while ( my $line = <$fh> ) {
+        chomp $line;
+        $line =~ s/^\s+//;
+        $line =~ s/\s+$//;
+
+        next if $line eq '';
+        next if $line =~ /^#/;
+
+        push( @lines, $line );
+    }
+    close $fh;
+
+    return @lines;
+}
+
 1;
